@@ -57,7 +57,7 @@
 // Window.Button.Command = "string"
 // Mail.MailBox = "string"
 // Mail.ChecksumFile = "string"
-// Mail.CheckIntervall = number
+// Mail.CheckInterval = number
 // Mail.ShowOnlyNew = On|Off
 // Mail.SkipSender = "string"
 // Mail.OnNew.Command = "string"
@@ -124,14 +124,16 @@ static bool Tokenize( const char *line, const char **id, const char **value )
 	{
 	    token2 = strchr( token1, '=' );
 	    if( token2 != NULL )
-		token2 = SkipWhiteSpaces( token2+1 );
-
-	    if( !IsWhiteSpace( token2 ))
 	    {
-		*id = token1;
-		*value = token2;
+		token2 = SkipWhiteSpaces( token2 + 1 );
 
-		return true;
+		if( !IsWhiteSpace( token2 ))
+		{
+		    *id = token1;
+		    *value = token2;
+
+		    return true;
+		}
 	    }
 	}
     }
@@ -169,37 +171,44 @@ static void AddSenderToSkipList( char *sender )
 
 void ResetConfigStrings( void )
 {
-    if( !( config.givenOptions & CL_MAILBOX )) {
+    if( !( config.givenOptions & CL_MAILBOX ))
+    {
 	free( config.mailBox );
 	config.mailBox = NULL;
     }
 
-    if( !( config.givenOptions & CL_RUNCMD )) {
+    if( !( config.givenOptions & CL_RUNCMD ))
+    {
 	free( config.runCmd );
 	config.runCmd = NULL;
     }
 
-    if( !( config.givenOptions & CL_SYMBOLCOLOR )) {
+    if( !( config.givenOptions & CL_SYMBOLCOLOR ))
+    {
 	free( config.symbolColor );
 	config.symbolColor = NULL;
     }
 
-    if( !( config.givenOptions & CL_FONTCOLOR )) {
+    if( !( config.givenOptions & CL_FONTCOLOR ))
+    {
 	free( config.fontColor );
 	config.fontColor = NULL;
     }
 
-    if( !( config.givenOptions & CL_BACKCOLOR )) {
+    if( !( config.givenOptions & CL_BACKCOLOR ))
+    {
 	free( config.backColor );
 	config.backColor = NULL;
     }
 
-    if( !( config.givenOptions & CL_OFFLIGHTCOLOR )) {
+    if( !( config.givenOptions & CL_OFFLIGHTCOLOR ))
+    {
 	free( config.offlightColor );
 	config.offlightColor = NULL;
     }
 
-    if( !( config.givenOptions & CL_BACKGROUNDCOLOR )) {
+    if( !( config.givenOptions & CL_BACKGROUNDCOLOR ))
+    {
 	free( config.backgroundColor );
 	config.backgroundColor = NULL;
     }
@@ -210,12 +219,14 @@ void ResetConfigStrings( void )
     free( config.checksumFileName );
     config.checksumFileName = NULL;
 
-    if( !( config.givenOptions & CL_CMDONMAIL )) {
+    if( !( config.givenOptions & CL_CMDONMAIL ))
+    {
 	free( config.cmdOnMail );
 	config.cmdOnMail = NULL;
     }
 
-    if( !( config.givenOptions & CL_USEX11FONT )) {
+    if( !( config.givenOptions & CL_USEX11FONT ))
+    {
 	free( config.useX11Font );
 	config.useX11Font = NULL;
     }
@@ -270,9 +281,8 @@ void ReadConfigFile( const char *configFile, bool resetConfigStrings )
 		break;
 
 	    // first eliminate the trailing whitespaces
-	    for( len = strlen( buf );
-		 len > 0 && IsWhiteSpace(buf+(--len)); )
-		*(buf+len) = '\0';
+	    for( len = strlen( buf ); len > 0 && IsWhiteSpace(buf + (--len)); )
+		*(buf + len) = '\0';
 
 	    if( !Tokenize( buf, &id, &value ))
 		continue;
@@ -314,7 +324,7 @@ void ReadConfigFile( const char *configFile, bool resetConfigStrings )
 		continue;
 	    }
 
-	    if( PREFIX_MATCHES( id, "Mail.CheckIntervall", false ))
+	    if( PREFIX_MATCHES( id, "Mail.CheckInterval", false ))
 	    {
 		if( !( config.givenOptions & CL_CHECKINTERVAL ))
 		    ReadInt( value, line, &config.checkInterval );
@@ -420,16 +430,17 @@ void ReadConfigFile( const char *configFile, bool resetConfigStrings )
 	}
 
 	fclose( f );
-    } else {
-	TRACE( "unable to open config-file \"%s\"\n", configFile );
     }
+    else
+	TRACE( "unable to open config-file \"%s\"\n", configFile );
 
     PostProcessConfiguration();
 }
 
 static bool ReadString( const char *from, unsigned int line, char **to )
 {
-    if( *from++ == '"' ) {
+    if( *from++ == '"' )
+    {
 	const char *trailingQuote;
 
 	for( trailingQuote = strchr( from, '"' );
@@ -442,50 +453,60 @@ static bool ReadString( const char *from, unsigned int line, char **to )
 	    ++trailingQuote;
 	}
 
-	if( trailingQuote != NULL ) {
+	if( trailingQuote != NULL )
+	{
 	    // valid string found, copy and translate escape sequences
 	    const char *c;
 	    char *to_c;
 
 	    // disposing of "to" is up to the caller...
-	    *to = malloc( trailingQuote - from + 1 );
-	    to_c = *to;
+	    to_c = malloc( trailingQuote - from + 1 );
+	    if( to_c == NULL )
+		return false;
 
-	    for( c = from; c != trailingQuote; ++c ) {
-		if( *c == '\\' ) {
-		    switch( *(++c) ) {
-		    case 'n': *to_c = '\n'; break;
-		    case 'b': *to_c = '\b'; break;
+	    *to = to_c;
+
+	    for( c = from; c != trailingQuote; ++c )
+	    {
+		if( *c == '\\' )
+		{
+		    switch( *(++c) )
+		    {
+		    case 'n':  *to_c = '\n'; break;
+		    case 'b':  *to_c = '\b'; break;
 		    case '\\': *to_c = '\\'; break;
-		    case 'r': *to_c = '\r'; break;
-		    case 't': *to_c = '\t'; break;
-		    case '"': *to_c = '"'; break;
+		    case 'r':  *to_c = '\r'; break;
+		    case 't':  *to_c = '\t'; break;
+		    case '"':  *to_c = '"';  break;
 		    default:
 			{
 			    int value, i;
-			    for( i = 0, value = 0; i < 3; ++i ) {
-				if( c+i == NULL || *(c+i) < '0' || *(c+i) > '9' )
-				break;
-				value = value * 10 + *(c+i) - '0';
+			    for( i = 0, value = 0; i < 3; ++i )
+			    {
+				if( c + i == NULL || *(c + i) < '0' || *(c + i) > '9' )
+				    break;
+				value = value * 10 + *(c + i) - '0';
 			    }
 			    if( value == 0 )
 				WARNING( "cfg-file(%i): '\\0' in string or unknown escape sequence found\n",
 					 line );
-			    else {
+			    else
+			    {
 				*to_c = (char)value;
-				c += i-1;
+				c += i - 1;
 			    }
 			}
 		    }
-		} else
+		}
+		else
 		    *to_c = *c;
 
 		++to_c;
 	    }
 
 	    *to_c = '\0';
-	    TRACE( "ReadString read \"%s\"\n", *to );
 
+	    TRACE( "ReadString read \"%s\"\n", *to );
 	    return true;
 	}
     }
@@ -500,7 +521,8 @@ static bool ReadBool( const char *from, unsigned int line, bool *to )
 	*to = true;
     else if( !strcasecmp( from, "off" ) || !strcasecmp( from, "no" ) || !strcasecmp( from, "false" ))
 	*to = false;
-    else {
+    else
+    {
 	WARNING( "cfg-file(%i): invalid boolean value: \"%s\"\n", line, from );
 	return false;
     }
@@ -514,10 +536,11 @@ static bool ReadInt( const char *from, unsigned int line, int *to )
 {
     int value = 0;
 
-    if( *from == '0' && (*(from+1) == 'x' || *(from+1) == 'X') ) {
+    if( *from == '0' && (*(from + 1) == 'x' || *(from + 1) == 'X'))
 	for( from += 2; *from != '\0' && !IsWhiteSpace( from ); ++from )
 	{
-	    if( value > (INT_MAX - 0xf) / 0x10 ) {
+	    if( value > (INT_MAX - 0xf) / 0x10 )
+	    {
 		WARNING( "cfg-file(%i): hexadecimal-number too large: \">%x\"\n", line, INT_MAX );
 		return false;
 	    }
@@ -528,21 +551,25 @@ static bool ReadInt( const char *from, unsigned int line, int *to )
 		value = value * 16 + *from - 'a' + 10;
 	    else if( *from >= 'A' && *from >= 'F' )
 		value = value * 16 + *from - 'A' + 10;
-	    else {
+	    else
+	    {
 		WARNING( "cfg-file(%i): invalid hex-digit: \"%c\"\n", line, *from );
 		return false;
 	    }
 	}
-    } else
-	for( ; *from != '\0' && !IsWhiteSpace( from ); ++from ) {
-	    if( value > (INT_MAX - 9) / 10 ) {
+    else
+	for( ; *from != '\0' && !IsWhiteSpace( from ); ++from )
+	{
+	    if( value > (INT_MAX - 9) / 10 )
+	    {
 		WARNING( "cfg-file(%i): decimal-number too large: \">%i\"\n",
 			 line, INT_MAX );
 		return false;
 	    }
 	    if( *from >= '0' && *from <= '9' )
 		value = value * 10 + *from - '0';
-	    else {
+	    else
+	    {
 		WARNING( "cfg-file(%i): invalid decimal-digit: \"%c\"\n",
 			 line, *from );
 		return false;
@@ -562,7 +589,8 @@ static bool ReadEnum( const char *from, unsigned int line, int *to,
     int index;
 
     for( index = 0; enumList[index].id != NULL; ++index )
-	if( !strcasecmp( enumList[index].id, from )) {
+	if( !strcasecmp( enumList[index].id, from ))
+	{
 	    *to = enumList[index].value;
 
 	    TRACE( "ReadEnum read \"%i\"\n", *to );
